@@ -1,5 +1,6 @@
 /*
  *  xfce4-mailwatch-plugin - a mail notification applet for the xfce4 panel
+ *  Copyright (c) 2013 Ján Sučan <sucan@runbox.com>
  *  Copyright (c) 2005-2008 Brian Tarricone <bjt23@cornell.edu>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -74,7 +75,7 @@
 #include <gtk/gtk.h>
 
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include "mailwatch-utils.h"
 #include "mailwatch.h"
@@ -497,7 +498,7 @@ gmail_config_timeout_spinbutton_changed_cb(GtkSpinButton *sb,
                                            gpointer user_data)
 {
     XfceMailwatchGMailMailbox *gmailbox = XFCE_MAILWATCH_GMAIL_MAILBOX(user_data);
-    gint value = gtk_spin_button_get_value_as_int(sb) * 60;
+    guint value = (guint) gtk_spin_button_get_value_as_int(sb) * 60;
     
     if(value == gmailbox->timeout)
         return FALSE;
