@@ -1,5 +1,6 @@
 /*
  *  xfce4-mailwatch-plugin - a mail notification applet for the xfce4 panel
+ *  Copyright (c) 2013 Ján Sučan <sucan@runbox.com>
  *  Copyright (c) 2005-2008 Brian Tarricone <bjt23@cornell.edu>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -58,7 +59,7 @@
 #include <gtk/gtk.h>
 
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include "mailwatch-net-conn.h"
 #include "mailwatch-utils.h"
@@ -184,7 +185,7 @@ imap_recv(XfceMailwatchIMAPMailbox *imailbox,
         g_error_free(error);
     }
 
-    if(recvd == len)
+    if((gsize)recvd == len)
         return -1;
 
     buf[recvd] = '\n';
@@ -272,7 +273,7 @@ imap_send_login_info(XfceMailwatchIMAPMailbox *imailbox,
     g_snprintf(buf, BUFSIZE, "%05d CAPABILITY\r\n", ++imailbox->imap_tag);
     bout = imap_send(imailbox, net_conn, buf);
     DBG("sent CAPABILITY (%d)", bout);
-    if(bout != strlen(buf))
+    if(bout != (gint)strlen(buf))
         goto cleanuperr;
     bin = imap_recv_command(imailbox, net_conn, buf, BUFSIZE);
     DBG("response from CAPABILITY (%d): %s", bin, bin>0?buf:"(nada)");
@@ -353,7 +354,7 @@ imap_send_login_info(XfceMailwatchIMAPMailbox *imailbox,
                ++imailbox->imap_tag, username, password);
     bout = imap_send(imailbox, net_conn, buf);
     DBG("sent login (%d)", bout);
-    if(bout != strlen(buf))
+    if(bout != (gint)strlen(buf))
         goto cleanuperr;
     
     /* and see if we actually got auth-ed */
@@ -418,7 +419,7 @@ imap_do_starttls(XfceMailwatchIMAPMailbox *imailbox,
     TRACE("entering");
     
     g_snprintf(buf, BUFSIZE, "%05d CAPABILITY\r\n", ++imailbox->imap_tag);
-    if(imap_send(imailbox, net_conn, buf) != strlen(buf))
+    if(imap_send(imailbox, net_conn, buf) != (gint)strlen(buf))
         return FALSE;
 
     bin = imap_recv_command(imailbox, net_conn, buf, BUFSIZE);
@@ -435,7 +436,7 @@ imap_do_starttls(XfceMailwatchIMAPMailbox *imailbox,
     }
     
     g_snprintf(buf, BUFSIZE, "%05d STARTTLS\r\n", ++imailbox->imap_tag);
-    if(imap_send(imailbox, net_conn, buf) != strlen(buf))
+    if(imap_send(imailbox, net_conn, buf) != (gint)strlen(buf))
         return FALSE;
     
     if(imap_recv_command(imailbox, net_conn, buf, BUFSIZE) < 0)
@@ -557,7 +558,7 @@ imap_check_mailbox(XfceMailwatchIMAPMailbox *imailbox,
     g_snprintf(buf, sizeof(buf), "%05d STATUS %s (UNSEEN)\r\n",
                ++imailbox->imap_tag, mailbox_name);
 
-    if(imap_send(imailbox, net_conn, buf) != strlen(buf))
+    if(imap_send(imailbox, net_conn, buf) != (gint)strlen(buf))
         return 0;
     DBG("  successfully sent cmd '%s'", buf);
     
@@ -859,7 +860,7 @@ imap_config_timeout_spinbutton_changed_cb(GtkSpinButton *sb,
                                           gpointer user_data)
 {
     XfceMailwatchIMAPMailbox *imailbox = user_data;
-    gint value = gtk_spin_button_get_value_as_int(sb) * 60;
+    guint value = gtk_spin_button_get_value_as_int(sb) * 60;
     
     if(imailbox->timeout == value)
         return;
@@ -919,7 +920,7 @@ imap_populate_folder_tree(XfceMailwatchIMAPMailbox *imailbox,
     
     g_snprintf(buf, BUFSIZE, "%05d LIST \"%s\" \"%%\"\r\n",
             ++imailbox->imap_tag, cur_folder);
-    if(imap_send(imailbox, net_conn, buf) != strlen(buf))
+    if(imap_send(imailbox, net_conn, buf) != (gint)strlen(buf))
         return FALSE;
     DBG("sent LIST: '%s'", buf);
     
@@ -1444,36 +1445,11 @@ imap_config_newmailfolders_btn_clicked_cb(GtkWidget *w, gpointer user_data)
     
     render = gtk_cell_renderer_pixbuf_new();
     gtk_tree_view_column_pack_start(col, render, FALSE);
-#if GTK_CHECK_VERSION(2, 6, 0)
     g_object_set(G_OBJECT(render),
                  "stock-id", GTK_STOCK_DIRECTORY,
                  "stock-size", GTK_ICON_SIZE_MENU,
                  NULL);
-#else
-    {
-        gint iw, ih;
-        GdkPixbuf *pix;
-        GList *icons = NULL;
-        GdkScreen *gscreen = gtk_widget_get_screen(treeview);
-        XfceIconTheme *itheme = xfce_icon_theme_get_for_screen(gscreen);
-        
-        icons = g_list_prepend(icons, "stock_open");
-        icons = g_list_prepend(icons, "stock_folder");
-        icons = g_list_prepend(icons, "stock_directory");
-        icons = g_list_prepend(icons, "gnome-fs-directory");
-        icons = g_list_prepend(icons, "folder");
-        
-        gtk_icon_size_lookup(GTK_ICON_SIZE_MENU, &iw, &ih);
-        pix = xfce_icon_theme_load_list(itheme, icons, iw);
-        if(pix) {
-            g_object_set(G_OBJECT(render), "pixbuf", pix, NULL);
-            g_object_unref(G_OBJECT(pix));
-        }
-        
-        g_list_free(icons);
-    }
-#endif
-    
+
     imailbox->render = render = gtk_cell_renderer_text_new();
     gtk_tree_view_column_pack_start(col, render, TRUE);
     gtk_tree_view_column_set_attributes(col, render,
@@ -1892,7 +1868,7 @@ imap_save_param_list(XfceMailwatchMailbox *mailbox)
     XfceMailwatchIMAPMailbox *imailbox = XFCE_MAILWATCH_IMAP_MAILBOX(mailbox);
     GList *params = NULL;
     XfceMailwatchParam *param;
-    gint i;
+    guint i;
     
     g_mutex_lock(imailbox->config_mx);
     
