@@ -1,5 +1,6 @@
 /*
  *  xfce4-mailwatch-plugin - a mail notification applet for the xfce4 panel
+ *  Copyright (c) 2013 Ján Sučan <sucan@runbox.com>
  *  Copyright (c) 2005 Pasi Orovuo <pasi.ov@gmail.com>
  *  Copyright (c) 2008 Brian Tarricone <bjt23@cornell.edu>
  *
@@ -48,7 +49,7 @@
 #include <gtk/gtk.h>
 
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include "mailwatch.h"
 
@@ -546,7 +547,7 @@ mh_save_param_list( XfceMailwatchMailbox *mailbox )
 static void
 mh_timeout_changed_cb( GtkWidget *spinner, XfceMailwatchMHMailbox *mh )
 {
-    gint value = gtk_spin_button_get_value_as_int( GTK_SPIN_BUTTON( spinner ) ) * 60;
+    guint value = gtk_spin_button_get_value_as_int( GTK_SPIN_BUTTON( spinner ) ) * 60;
 
     DBG( "-->>" );
 
