@@ -1,5 +1,6 @@
 /*
  *  xfce4-mailwatch-plugin - a mail notification applet for the xfce4 panel
+ *  Copyright (c) 2013 Ján Sučan <sucan@runbox.com>
  *  Copyright (c) 2008 Brian Tarricone <bjt23@cornell.edu>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -96,7 +97,7 @@ struct _XfceMailwatchNetConn
     const gchar *line_terminator;
 
     gint fd;
-    guint actual_port;
+    gint actual_port;
 
     guchar *buffer;
     gsize buffer_len;
@@ -199,6 +200,7 @@ my_g_mutex_unlock(void **priv)
 
 
 
+#ifdef HAVE_SSL_SUPPORT
 static gboolean
 xfce_mailwatch_net_conn_tls_handshake(XfceMailwatchNetConn *net_conn,
                                       GError **error)
@@ -209,7 +211,7 @@ xfce_mailwatch_net_conn_tls_handshake(XfceMailwatchNetConn *net_conn,
     TIMER_START;
     do {
         ret = gnutls_handshake(net_conn->gt_session);
-    } while((GNUTLS_E_AGAIN == ret || GNUTLS_E_INTERRUPTED == ret)
+    } while((ret == GNUTLS_E_AGAIN || ret == GNUTLS_E_INTERRUPTED)
             && !TIMER_EXPIRED(RECV_TIMEOUT) && SHOULD_CONTINUE(net_conn));
 
     if(ret != GNUTLS_E_SUCCESS) {
@@ -219,12 +221,12 @@ xfce_mailwatch_net_conn_tls_handshake(XfceMailwatchNetConn *net_conn,
         if(!SHOULD_CONTINUE(net_conn)) {
             code = XFCE_MAILWATCH_ERROR_ABORTED;
             reason = _("Operation aborted");
-        } else if(GNUTLS_E_AGAIN == ret || GNUTLS_E_INTERRUPTED == ret)
+        } else if(ret == GNUTLS_E_AGAIN || ret == GNUTLS_E_INTERRUPTED)
             reason = strerror(ETIMEDOUT);
         else
             reason = gnutls_strerror(ret);
         if(error)
-            g_set_error(error, XFCE_MAILWATCH_ERROR, code, reason);
+            g_set_error(error, XFCE_MAILWATCH_ERROR, code, "%s", reason);
         g_critical("XfceMailwatch: TLS handshake failed: %s", reason);
 
         return FALSE;
@@ -234,6 +236,7 @@ xfce_mailwatch_net_conn_tls_handshake(XfceMailwatchNetConn *net_conn,
 
     return TRUE;
 }
+#endif
 
 static XfceMailwatchNetConnStatus
 xfce_mailwatch_net_conn_do_connect(XfceMailwatchNetConn *net_conn,
@@ -247,10 +250,10 @@ xfce_mailwatch_net_conn_do_connect(XfceMailwatchNetConn *net_conn,
     TIMER_START;
     do {
         ret = connect(net_conn->fd, addr, addrlen);
-    } while(ret < 0 && (EINTR == errno || EAGAIN == errno)
+    } while(ret < 0 && (errno == EINTR || errno == EAGAIN)
             && !TIMER_EXPIRED(RECV_TIMEOUT) && SHOULD_CONTINUE(net_conn));
 
-    if(!ret || (ret < 0 && EINPROGRESS == errno))  /* we're done here */
+    if(!ret || (ret < 0 && errno == EINPROGRESS))  /* we're done here */
         return XFCE_MAILWATCH_NET_CONN_SUCCESS;
 
     /* this is a little different.  the only 'fatal' error at this
@@ -292,7 +295,7 @@ xfce_mailwatch_net_conn_get_connect_status(XfceMailwatchNetConn *net_conn,
 
         /* wait until the connect attempt finishes */
         if(select(FD_SETSIZE, NULL, &wfd, NULL, &tv) < 0) {
-            if(EINTR == errno)
+            if(errno == EINTR)
                 continue;
             /* FIXME: should a select() failure actually be fatal? */
             return XFCE_MAILWATCH_NET_CONN_ERROR;
@@ -356,7 +359,7 @@ xfce_mailwatch_net_conn_get_connect_status(XfceMailwatchNetConn *net_conn,
 
 
 void
-xfce_mailwatch_net_conn_init()
+xfce_mailwatch_net_conn_init(void)
 {
     static gboolean __inited = FALSE;
 
@@ -495,7 +498,7 @@ xfce_mailwatch_net_conn_get_addrinfo(XfceMailwatchNetConn *net_conn,
             g_set_error(error, XFCE_MAILWATCH_ERROR, 0,
                         _("Could not find host \"%s\": %s"),
                         net_conn->hostname,
-                        EAI_SYSTEM == ret ? strerror(errno)
+                        ret == EAI_SYSTEM ? strerror(errno)
                                           : gai_strerror(ret));
         }
         return FALSE;
@@ -598,10 +601,6 @@ gboolean
 xfce_mailwatch_net_conn_make_secure(XfceMailwatchNetConn *net_conn,
                                     GError **error)
 {
-#ifdef HAVE_SSL_SUPPORT
-    const int cert_type_prio[2] = { GNUTLS_CRT_X509, 0 };
-#endif
-
     g_return_val_if_fail(net_conn && (!error || !*error), FALSE);
     g_return_val_if_fail(net_conn->fd != -1, FALSE);
     g_return_val_if_fail(!net_conn->is_secure, TRUE);
@@ -615,15 +614,16 @@ xfce_mailwatch_net_conn_make_secure(XfceMailwatchNetConn *net_conn,
     
     /* init the session and set it up */
     gnutls_init(&net_conn->gt_session, GNUTLS_CLIENT);
-    gnutls_set_default_priority(net_conn->gt_session);
-    gnutls_certificate_type_set_priority(net_conn->gt_session, cert_type_prio);
+    gnutls_priority_set_direct (net_conn->gt_session, "NORMAL", NULL); 
     gnutls_credentials_set(net_conn->gt_session, GNUTLS_CRD_CERTIFICATE,
                            net_conn->gt_creds);
     gnutls_transport_set_ptr(net_conn->gt_session,
                              (gnutls_transport_ptr_t)net_conn->fd);
+#if GNUTLS_VERSION_NUMBER < 0x020c00 
     if(fcntl(net_conn->fd, F_GETFL) & O_NONBLOCK)
         gnutls_transport_set_lowat(net_conn->gt_session, 0);
-    
+#endif    
+
     if(!xfce_mailwatch_net_conn_tls_handshake(net_conn, error)) {
 #if 0
         gnutls_bye(net_conn->gt_session, GNUTLS_SHUT_RDWR);
@@ -675,12 +675,12 @@ xfce_mailwatch_net_conn_send_data(XfceMailwatchNetConn *net_conn,
                                          buf + totallen - bytesleft,
                                          bytesleft);
 
-                if(GNUTLS_E_REHANDSHAKE == ret) {
+                if(ret == GNUTLS_E_REHANDSHAKE) {
                     if(!xfce_mailwatch_net_conn_tls_handshake(net_conn, error))
                         return -1;
                     ret = GNUTLS_E_AGAIN;
                 }
-            } while((GNUTLS_E_INTERRUPTED == ret || GNUTLS_E_AGAIN == ret)
+            } while((ret == GNUTLS_E_INTERRUPTED || ret == GNUTLS_E_AGAIN)
                     && !TIMER_EXPIRED(RECV_TIMEOUT) && SHOULD_CONTINUE(net_conn));
 
             if(ret < 0) {
@@ -712,7 +712,7 @@ xfce_mailwatch_net_conn_send_data(XfceMailwatchNetConn *net_conn,
         TIMER_START;
         do {
             bout = send(net_conn->fd, buf, buf_len, MSG_NOSIGNAL);
-        } while(bout < 0 && (EINTR == errno || EAGAIN == errno)
+        } while(bout < 0 && (errno == EINTR || errno == EAGAIN)
                 && !TIMER_EXPIRED(RECV_TIMEOUT) && SHOULD_CONTINUE(net_conn));
     }
 
@@ -723,7 +723,7 @@ xfce_mailwatch_net_conn_send_data(XfceMailwatchNetConn *net_conn,
         if(!SHOULD_CONTINUE(net_conn)) {
             code = XFCE_MAILWATCH_ERROR_ABORTED;
             reason = _("Operation aborted");
-        } else if(EINTR == errno || EAGAIN == errno)
+        } else if(errno == EINTR || errno == EAGAIN)
             reason = strerror(ETIMEDOUT);
         else
             reason = strerror(errno);
@@ -756,50 +756,65 @@ xfce_mailwatch_net_conn_recv_internal(XfceMailwatchNetConn *net_conn,
         if(!block)
             tv.tv_sec = 0;
 
+#ifdef HAVE_SSL_SUPPORT
+        /* Read data from the gnutls read buffer, first. */
+        if (net_conn->is_secure
+            && (ret = gnutls_record_check_pending(net_conn->gt_session)) > 0) {
+            break;
+        }
+#endif
         ret = select(FD_SETSIZE, &rfd, NULL, NULL, &tv);
         if(ret > 0 && FD_ISSET(net_conn->fd, &rfd))
             break;
-        else if(ret < 0 && EINTR != errno) {
+        else if(ret < 0 && errno != EINTR) {
             g_set_error(error, XFCE_MAILWATCH_ERROR,
-                        XFCE_MAILWATCH_ERROR_FAILED, strerror(errno));
+                        XFCE_MAILWATCH_ERROR_FAILED, "%s", strerror(errno));
             return -1;
         } else if(!block)
             return 0;
-    } while(ret < 0 && EINTR == errno && !TIMER_EXPIRED(RECV_TIMEOUT)
-            && SHOULD_CONTINUE(net_conn));
+    } while((ret == 0 || (ret < 0 && errno == EINTR))
+            && !TIMER_EXPIRED(RECV_TIMEOUT) && SHOULD_CONTINUE(net_conn));
 
-    if(!SHOULD_CONTINUE(net_conn)) {
+    if(ret < 0 && errno != EINTR) {
         if(error) {
             g_set_error(error, XFCE_MAILWATCH_ERROR,
-                        XFCE_MAILWATCH_ERROR_ABORTED, _("Operation aborted"));
+                        XFCE_MAILWATCH_ERROR_FAILED, "%s", strerror(errno));
+        }
+        return -1;
+    } else if(!SHOULD_CONTINUE(net_conn)) {
+        if(error) {
+            g_set_error(error, XFCE_MAILWATCH_ERROR,
+                        XFCE_MAILWATCH_ERROR_ABORTED, "%s",
+                        _("Operation aborted"));
         }
         return -1;
     } else if(TIMER_EXPIRED(RECV_TIMEOUT)) {
         if(error) {
             g_set_error(error, XFCE_MAILWATCH_ERROR,
-                        XFCE_MAILWATCH_ERROR_FAILED, strerror(ETIMEDOUT));
+                        XFCE_MAILWATCH_ERROR_FAILED, "%s",
+                        strerror(ETIMEDOUT));
         }
         return -1;
     }
 
 #ifdef HAVE_SSL_SUPPORT
     if(net_conn->is_secure) {
-        gint ret;
+        gint gret;
         code = XFCE_MAILWATCH_ERROR_FAILED;
 
         TIMER_START;
         do {
-            ret = gnutls_record_recv(net_conn->gt_session, buf, buf_len);
+            gret = gnutls_record_recv(net_conn->gt_session, buf, buf_len);
 
-            if(GNUTLS_E_REHANDSHAKE == ret) {
+            if(gret == GNUTLS_E_REHANDSHAKE) {
                 if(!xfce_mailwatch_net_conn_tls_handshake(net_conn, error))
                     return -1;
-                ret = GNUTLS_E_AGAIN;
+                gret = GNUTLS_E_AGAIN;
             }
-        } while((GNUTLS_E_INTERRUPTED == ret || GNUTLS_E_AGAIN == ret)
+        } while((gret == GNUTLS_E_INTERRUPTED || gret == GNUTLS_E_AGAIN)
                 && !TIMER_EXPIRED(RECV_TIMEOUT) && SHOULD_CONTINUE(net_conn));
         
-        if(ret < 0) {
+        if(gret < 0) {
             if(error) {
                 if(!SHOULD_CONTINUE(net_conn)) {
                     code = XFCE_MAILWATCH_ERROR_ABORTED;
@@ -807,7 +822,7 @@ xfce_mailwatch_net_conn_recv_internal(XfceMailwatchNetConn *net_conn,
                 } else if(TIMER_EXPIRED(RECV_TIMEOUT))
                     reason = strerror(ETIMEDOUT);
                 else
-                    reason = gnutls_strerror(ret);
+                    reason = gnutls_strerror(gret);
 
                 g_set_error(error, XFCE_MAILWATCH_ERROR, code,
                             _("Failed to receive encrypted data: %s"),
@@ -816,20 +831,20 @@ xfce_mailwatch_net_conn_recv_internal(XfceMailwatchNetConn *net_conn,
 
             bin = -1;
         } else
-            bin = ret;
+            bin = gret;
     } else
 #endif
     {
-        gint ret;
+        gint pret;
         code = XFCE_MAILWATCH_ERROR_FAILED;
 
         TIMER_START;
         do {
-            ret = recv(net_conn->fd, buf, buf_len, MSG_NOSIGNAL);
-        } while(ret < 0 && (EINTR == errno || EAGAIN == errno)
+            pret = recv(net_conn->fd, buf, buf_len, MSG_NOSIGNAL);
+        } while(pret < 0 && (errno == EINTR || errno == EAGAIN)
                 && !TIMER_EXPIRED(RECV_TIMEOUT) && SHOULD_CONTINUE(net_conn));
 
-        if(ret < 0) {
+        if(pret < 0) {
             if(error) {
                 if(!SHOULD_CONTINUE(net_conn)) {
                     code = XFCE_MAILWATCH_ERROR_ABORTED;
@@ -844,7 +859,7 @@ xfce_mailwatch_net_conn_recv_internal(XfceMailwatchNetConn *net_conn,
             }
             bin = -1;
         } else
-            bin = ret;
+            bin = pret;
     }
 
     return bin;
@@ -869,7 +884,7 @@ xfce_mailwatch_net_conn_recv_data(XfceMailwatchNetConn *net_conn,
             net_conn->buffer = NULL;
             net_conn->buffer_len = 0;
 
-            if(bin == buf_len)
+            if(bin == (gint)buf_len)
                 return bin;
             else {
                 buf += bin;
@@ -944,11 +959,13 @@ xfce_mailwatch_net_conn_recv_line(XfceMailwatchNetConn *net_conn,
         }
     } while(!p);
 
-    if(buf_len < p - (gchar *)net_conn->buffer) {
+    if((gint)buf_len < p - (gchar *)net_conn->buffer) {
         if(error) {
+            gchar *bl = g_strdup_printf("%" G_GSIZE_FORMAT, buf_len);
             g_set_error(error, XFCE_MAILWATCH_ERROR, 0,
-                        _("Buffer is not large enough to hold a full line (%d < %d)"),
-                        buf_len, p - (gchar *)net_conn->buffer);
+                        _("Buffer is not large enough to hold a full line (%s < %d)"),
+                        bl, (gint)(p - (gchar *)net_conn->buffer));
+            g_free(bl);
         }
         return -1;
     }
